:orphan:

..
   This file is automatically run when the docs are built.
   It generates the full API documentation using sphinx extension autosummary.
   The results are stored in docs/_autosummary.

.. autosummary::
   :toctree: ../_autosummary
   :template: custom-module-template.rst
   :recursive:

   genomepy
